@@ -3,8 +3,10 @@ function _aws_cdk_aws_sqs_QueuePolicyProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.queues))
-            _aws_cdk_aws_sqs_IQueue(p.queues);
+        if (p.queues != null)
+            for (const o of p.queues)
+                if (!visitedObjects.has(o))
+                    _aws_cdk_aws_sqs_IQueue(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -61,8 +63,10 @@ function _aws_cdk_aws_sqs_CfnQueueProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
